unit UDataMod;

interface

uses
  SysUtils, Classes, Dialogs, Forms, Controls;

type
  DataSetR = array of real;
  DataSetVar = array [1..7] of DataSetR;
  LineSet  = array of string;

type
  TDataMod = class(TDataModule)
    procedure DataModuleCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    FileName,
    InputFileName,
    FirstName,
    OriginalName,
    Title1, Title2,
    GrTitle1, GrTitle2,
    GrTitle3, Code,
    GroupTitle, TimeStep    : string;
    Variable                : DataSetVar;
    NrOfData : integer;
    FileLine, ErrorLines,
    WarningLines            : LineSet;
    NrOfLines, NrOfWarnings : integer;
    MonthNr                 : integer;
    FirstTime, GroupNotRead,
    EndOfCalc               : boolean;
    Area                    : real;
    First, Kd, Kf, Kr, 
    Ns, Nm, Ky              : integer;
    A, B,
    Lc, Io,
    IaA, Epa,
    IaB, EpB,
    Pp, EpU,
    FsA, FsB, FsU,
    Gi, Go,
    SiU, SoU,
    SoA, SoB,
    Gw, Fw,
    Gu, Frd   : array[1..2] of real;
    RcA, RcB  : array[1..2] of integer;
    Dr, Ptr, Dx, Ptx, Dq, Ptq : real;
    Per, Flr, Pex, Flx, Peq, Flq : real;
    Cx0, Cq0, Cic, Ch, Cp : real;
    CA0, CB0, CU0, Dw0, Dc : real;
    Dd, QH1, QH2 : real;
    Cxa0, Cxb0   : real;
    MainStr      : array [1..7] of string[12];
    GridStr      : array [1..7] of array of string[6];
    NrOfitems    : integer;
    GroupMark    : string[5];
    procedure ReadInputFile;
    procedure WriteInputFile(const DocName: string);
    procedure ReadErrorLines
              (var ErrorPresent : boolean; var NrOfErrors : integer);
    procedure ReadWarningLines
              (var WarningPresent : boolean; var NrOfWarnings : integer);
    procedure ReadOutputLines(const DocName: string;
                              var Reading : boolean);
    procedure ReadOutputGroup(Signal : string);
    procedure ReadGroupData;
    procedure WriteOutputGroup(const DocName: string);
    procedure WriteOutputLines(const DocName: string);
    function  StringToFlo(Str : string) : double;
    function  Question(const Query: string): boolean;
  end;

var
  DataMod: TDataMod;

implementation

{$R *.dfm}


{******************************************************************************
 read/write input file
 ******************************************************************************}


procedure TDataMod.ReadInputFile;
{-------------------------------}
var  InFile   : textfile;
     k        : byte;
     StepStr  : string;
begin
  Assignfile(InFile, FileName);
  {$I-} Reset(InFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "' + filename + '"could not be opened. It may be ' +
      'dameged or in use by another program.');
    exit;
  end;
  NrOfLines := 0;
  while not eof (InFile) do
  begin
    readln(InFile);
    NrOfLines := NrOfLines+1;
  end;
  reset (InFile);
  readln(InFile, Title1);
  readln(InFile, Title2);
  readln (InFile);
  readln (InFile, Area, Nm, Kd, StepStr);
  while Pos(' ',StepStr)>0 do delete(StepStr,Pos(' ',StepStr),1);
  if TimeStep='' then
     ShowMessage (' This is an older inputfile. Please check the time step');
  TimeStep:='Month';
  if StepStr='Week' then TimeStep:='Week';
  if StepStr='Day' then TimeStep:='Day';
  readln (InFile);
  for k:=1 to Ns do read (InFile,A[k],B[k]);
  readln (InFile);
  readln (InFile);
  for k:=1 to Ns do read (InFile,RcA[k],RcB[k]);
  readln (InFile);
  readln (inFile);
  for k:=1 to Ns do read (InFile,Lc[k],Io[k]);
  readln (InFile);
  readln (InFile);
  for k:=1 to Ns do read (InFile,IaA[k],EpA[k]);
  readln (InFile);
  readln (InFile);
  for k:=1 to Ns do read (InFile,IaB[k],EpB[k]);
  readln (InFile);
  readln (InFile);
  for k:=1 to Ns do read (InFile,Pp[k],EpU[k]);
  readln (InFile);
  readln (InFile);
  for k:=1 to Ns do read (InFile,FsA[k],FsB[k],FsU[k]);
  readln (InFile);
  readln (InFile);
//  for k:=1 to Ns do read (InFile,FsU[k]);
//  readln (InFile);
//  readln (InFile);
  {for k:=1 to Ns do} read (InFile,Gi[1],Go[1]);
  readln (InFile);
  readln (InFile);
  {for k:=1 to Ns do} read (InFile,SiU[1],SoU[1]);
  readln (InFile);
  readln (InFile);
  {for k:=1 to Ns do} read (InFile,SoA[1],SoB[1]);
  readln (InFile);
  readln (InFile);
  {for k:=1 to Ns do} read (InFile,Gw[1],Fw[1]);
  readln (InFile);
  readln (InFile);
  readln (InFile, Dr, Ptr, Dx, Ptx, Dq, Ptq);
  readln (InFile);
  readln (InFile, Per, Flr, Pex, Flx, Peq, Flq);
  readln (InFile);
  readln (InFile, Cx0, Cq0, Cic, Ch, Cp);
  readln (InFile);
  readln (InFile, CA0, CB0, CU0, Dw0, Dc);
  readln (InFile);
  if Kd=1 then
  begin
    readln (InFile, Dd, QH1, QH2, Gu[1]);
    readln (InFile);
    readln (InFile, Cxa0, Cxb0, Frd[1]);
  end;
  Closefile(InFile);
end; {TDataMod.ReadInputFile}
{---------------------------}



procedure TDataMod.WriteInputFile (const DocName: string);
{--------------------------------------------------------}
var  InFile : textfile;
     i,j,k,m : byte;
     HlpStr : string;
     Blines : array [1..23] of String;
     sp0, sp3, sp4, sp5, sp6, sp7, sp8 : string;
     AB : real;
begin
  Assignfile(InFile, DocName);
  {$I-} Rewrite(InFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "' + DocName + '"could not be opened. It ' +
      'may be damaged or in use by another program.');
    exit;
  end;
  writeln(InFile, Title1);
  writeln(InFile, Title2);

  BLines[1]:='Explanatory text:';
  BLines[2]:='Additional explanatory text:';
  BLines[3]:='1.      Area    Nm      Kd      Tst';
  BLines[6]:='2.   ';
  BLines[7]:='3.   ';
  BLines[8]:='4.   ';
  BLines[9]:='5.   ';
  BLines[10]:='6.   ';
  BLines[11]:='7.   ';
  BLines[12]:='8.   ';
  BLines[14]:='9.   ';
  BLines[15]:='10.  ';
  BLines[16]:='11.  ';
  BLines[17]:='12.  ';
  BLines[18]:='13.     Dr      Ptr     Dx      Ptx     Dq      Ptq';
  BLines[19]:='14.     Per     Flr     Pex     Flx     Peq     Flq';
  BLines[20]:='15.     Cx0     Cq0     Cic     Ch      Cp';
  BLines[21]:='16.     CA0     CB0     CU0     Dw0     Dc';
  BLines[22]:='17.     Dd      QH1     QH2  ';
  BLines[23]:='18.     Cxa0    Cxb0 ';
  for k:=1 to Ns do
    begin
      str(k:1, HlpStr);
//      BLines[5]:= BLines[ 5]+'   Ts'+HlpStr+ '  ';
      BLines[6]:= BLines[ 6]+'   A       B   ';
      BLines[7]:= BLines[ 7]+'   RcA     RcB ';
      BLines[8]:= BLines[ 8]+'   Lc      Io  ';
      BLines[9]:= BLines[ 9]+'   IaA     EpA ';
      BLines[10]:=BLines[10]+'   IaB     EpB ';
      BLines[11]:=BLines[11]+'   Pp      EpU ';
      BLines[12]:=BLines[12]+'   FsA     FsB     FsU';
//      BLines[13]:=BLines[13]+'   FsU ';
      BLines[14]:=BLines[14]+'   Gi      Go  ';
      BLines[15]:=BLines[15]+'   SiU     SoU ';
      BLines[16]:=BLines[16]+'   SoA     SoB ';
      BLines[17]:=BLines[17]+'   Gw      Fw  ';
      BLines[22]:=BLines[22]+'   Gu  ';
      BLines[23]:=BLines[23]+'   Frd ';
    end;
  sp3 := '   ';
  sp4 := '    ';
  sp5 := '     ';
  sp6 := '      ';
  sp7 := '       ';
  sp8 := '        ';
  writeln (InFile,BLines[3]);
  writeln (InFile,sp4,Area:8:1,sp4,Nm,sp7,Kd,sp4,'   ',TimeStep);
//  writeln (InFile,BLines[4]);
//  writeln (InFile,sp7,' ',Nm,sp6,Ky);
//  writeln (InFile,BLines[5]);
//  write (InFile,sp3);
//  for k:=1 to Ns do write (InFile,Ts[k]:8:1);
//  writeln (InFile);
  writeln (InFile,BLines[6]);
  write (InFile,sp4);
  for k:=1 to Ns do write (InFile,A[k]:8:2,B[k]:8:2);
  writeln (InFile);
  writeln (InFile,BLines[7]);
  write (InFile,' ');
  for k:=1 to Ns do write (InFile,RcA[k]:8,RcB[k]:8);
  writeln (InFile);
  writeln (InFile,BLines[8]);
  write (InFile,sp5);
  for k:=1 to Ns do write (InFile,Lc[k]:8:3,Io[k]:8:5);
  writeln (InFile);
  writeln (InFile,BLines[9]);
  write (InFile,sp5);
  for k:=1 to Ns do
      if A[k]>0 then
         write (InFile,IaA[k]:8:5,EpA[k]:9:5)
      else
         write (InFile,IaA[k]:5:0,EpA[k]:8:0);
  writeln (InFile);
  writeln (InFile,BLines[10]);
  write (InFile,sp5);
  for k:=1 to Ns do
      if (B[k]>0) and (EpB[k]>=0) then
         write (InFile,IaB[k]:8:5,EpB[k]:9:5)
      else
         write (InFile,IaB[k]:5:0,EpB[k]:8:0);
  writeln (InFile);
  writeln (InFile,BLines[11]);
  write (InFile,sp5);
  for k:=1 to Ns do
  begin
      AB:=A[k]+B[k];
      if A[k]=-1 then AB:=B[k];
      if B[k]=-1 then AB:=A[k];
      if AB<1 then
         write (InFile,Pp[k]:8:5,EpU[k]:9:5)
      else
         write (InFile,Pp[k]:8:5,EpU[k]:5:0);
  end;
  writeln (InFile);
  writeln (InFile,BLines[12]);
  write (InFile,sp4);
  for k:=1 to Ns do write (InFile,FsA[k]:8:2,FsB[k]:8:2,FsU[k]:8:2);
  writeln (InFile);
  writeln (InFile,BLines[14]);
  write (InFile,sp5);
  for k:=1 to Ns do write (InFile,Gi[k]:8:5,Go[k]:8:5);
  writeln (InFile);
  writeln (InFile,BLines[15]);
  write (InFile,sp5);
  for k:=1 to Ns do
  begin
      AB:=A[k]+B[k];
      if A[k]=-1 then AB:=B[k];
      if B[k]=-1 then AB:=A[k];
      if AB<1 then
         write (InFile,SiU[k]:8:5,SoU[k]:9:5)
      else
         write (InFile,SiU[k]:5:0,SoU[k]:8:0);
  end;
  writeln (InFile);
  writeln (InFile,BLines[16]);
  write (InFile,sp5);
  for k:=1 to Ns do
  begin
      if (A[k]>0) and (SoA[k]>=0) then
         write (InFile,SoA[k]:8:5)
      else
         write (InFile,SoA[k]:5:0);
      if (B[k]>0) and (SoB[k]>=0) then
         write (InFile,SoB[k]:8:5)
      else
         write (InFile,SoB[k]:5:0);
  end;
  writeln (InFile);
  writeln (InFile,BLines[17]);
  write (InFile,sp5);
  for k:=1 to Ns do write (InFile,Gw[k]:8:5,Fw[k]:8:3);
  writeln (InFile);
  writeln (InFile,BLines[18]);
  if Dq>9.999 then
    writeln (InFile, sp4, Dr:8:2,Ptr:8:2,Dx:8:2,Ptx:8:2,Dq:9:2,Ptq:7:2)
  else
    writeln (InFile, sp4, Dr:8:2,Ptr:8:2,Dx:8:2,Ptx:8:2,Dq:8:2,Ptq:8:2);
  writeln (InFile,BLines[19]);
  writeln (InFile, sp5, Per:8:3,Flr:7:2,Pex:9:3,Flx:7:2,Peq:9:3,Flq:7:2);
  writeln (InFile,BLines[20]);
  sp0:=sp3;
  if Cx0>=10 then sp0:=sp4;
  j:=8;
  if Cq0>=10 then j:=7;
  i:=8;
  if Ch>=10 then i:=9;
  m:=8;
  if Ch>=10 then m:=7;
  writeln (InFile, sp0, Cx0:8:3, Cq0:8:3, Cic:j:3, Ch:i:3, Cp:m:3);
  writeln (InFile,BLines[21]);
  writeln (InFile, sp3, CA0:8:3, CB0:8:3, CU0:8:3, Dw0:9:2, Dc:8:2);
  if Kd=1 then
  begin
    writeln (InFile,BLines[22]);
    write (InFile, sp4, Dd:8:2, QH1:10:4, QH2:8:4);
    write (InFile,Gu[1]:7:3);
    if Ns>1 then for k:=2 to Ns do write (InFile,Gu[k]:8:3);
    writeln (InFile);
    writeln (InFile,BLines[23]);
    write (InFile, sp3, Cxa0:8:3, Cxb0:8:3,' ');
    write (InFile,Frd[1]:7:3);
    if Ns>0 then for k:=1 to Ns do write (InFile,Frd[k]:8:2);
    writeln (InFile);
  end;
  writeln (InFile);
  writeln (InFile,'If the value -1 occurs it means: not applicable in this'+
                  ' case.');
  Closefile(InFile);
end; {TDataMod.WriteInputFile}
{----------------------------}


{******************************************************************************
 read/write output file
 ******************************************************************************}


procedure TDataMod.ReadErrorLines
          (var ErrorPresent : boolean; var NrOfErrors : integer);
{---------------------------------------------------------------}
var ErrorFile : textfile;
    i, k : integer;
    DumLine : string;
begin
    Assignfile (ErrorFile,'Error.lst');
    reset (ErrorFile);
    k:=0;
    while not eof (ErrorFile) do
    begin
      readln (ErrorFile,DumLine);
      k:=k+1;
    end;
    ErrorPresent:=false;
    if k>=3 then
    begin
      reset (ErrorFile);
      ErrorPresent:=true;
      setlength (ErrorLines,k);
      for i:=0 to k-1 do readln (ErrorFile,ErrorLines[i]);
      NrOfErrors:=k;
    end;
    closefile (ErrorFile);
end; {procedure TDataMod.ReadErrorLines}
{--------------------------------------}



procedure TDataMod.ReadWarningLines
          (var WarningPresent : boolean; var NrOfWarnings : integer);
{-------------------------------------------------------------------}
var WarningFile : textfile;
    i, k : integer;
    DumLine : string;
begin
    Assignfile (WarningFile,'warning.lst');
    reset (WarningFile);
    k:=0;
    while not eof (WarningFile) do
    begin
      readln (WarningFile,DumLine);
      k:=k+1;
    end;
    WarningPresent:=false;
    if k>=3 then
    begin
      reset (WarningFile);
      WarningPresent:=true;
      setlength (WarningLines,k);
      for i:=0 to k-1 do readln (WarningFile,WarningLines[i]);
      NrOfWarnings:=k;
    end;
    closefile (WarningFile);
end; {procedure TDataMod.ReadWarningLines}
{----------------------------------------}



procedure TDataMod.ReadOutputLines(const DocName: string;
                                   var Reading : boolean);
{--------------------------------------------------------}
var  OutFile: textfile;
     k: integer;
     DetectStr : string[8];
begin
  Reading:=true;
  AssignFile(OutFile,DocName);
  {$I-} Reset(OutFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "' + DocName + '"could not be opened. It may be ' +
      'damaged or in use by another program.');
    Reading:=false;
    exit;
  end;
  k:=0;
  while not eof(OutFile) do
  begin
    k:=k+1;
    SetLength (FileLine,k);
    readln(OutFile,FileLine[k-1]);
  end;
  NrOfLines:=k;
  reset (OutFile);
  for K:=1 to 14 do readln (OutFile);
  read (OutFile,DetectStr);
  if DetectStr='  MONTH:' then TimeStep:='Month';
  if DetectStr='   WEEK:' then TimeStep:='Week';
  if DetectStr='   DAY:' then TimeStep:='Day';
  Close(OutFile);
end; {TDataMod.ReadOutputLines}
{-----------------------------}



procedure TDataMod.ReadOutputGroup(Signal : string);
{--------------------------------------------------}
label 1;
var  OutFile  : textfile;
     Code     : string[2];
     DetectIt : string[8];
     HlpStr   : string[8];
     DetectStr : string[8];
     k,SkipNr    : integer;
begin
  FileName:=changefileext(FileName,'.res');
  AssignFile(OutFile,FileName);
  {$I-} Reset(OutFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "'+FileName+'"could not be opened. It may be ' +
      'damaged or in use by another program.');
    exit;
  end;
  while not eof (OutFile) do
  begin
    Code:='';
    while Code<>' #' do
          if not eof (OutFile) then readln (OutFile,Code)
          else goto 1;
    for k:=1 to 8 do
        readln (OutFile,DetectIt);
    read (OutFile,DetectIt);
    if (DetectIt='  MONTH:') or (DetectIt='   WEEK:')
       or (DetectIt='   DAY: ') then
      begin
        readln (OutFile,Nm);
        readln (OutFile);
      end;
  end;
1:reset (OutFile);
  Code:='';
  while Code<>' #' do
        if not eof (OutFile) then readln (OutFile,Code)
        else goto 1;
  for k:=1 to 8 do
      readln (OutFile,DetectIt);
  read (OutFile,DetectIt);
  DetectStr:=DetectIt;
  TimeStep:='Month';
  if DetectIt= '   DAY: ' then Timestep:='Day';
  if DetectIt= '   WEEK:' then Timestep:='Week';
  if TimeStep='Week' then DetectStr:='   WEEK:';
  if TimeStep='Day'  then DetectStr:='   DAY: ';

  reset (OutFile);

  NrOfData := 0;
  Nm:=Nm+1;
  SkipNr := 9;
  NrOfitems := 7;
  if Signal='CrA' then NrOfitems := 4;
  if (Signal='Cxf') then
  begin
    SkipNr := 10;
    NrOfitems := 7;
  end;
  if (Signal='Gd') then
  begin
    SkipNr := 6;
    NrOfitems := 6;
  end;
  if (Signal='LrA') then
  begin
    SkipNr := 4;
    NrOfitems := 4;
  end;
  if (Signal='RrA') then
  begin
    SkipNr := 5;
    NrOfitems := 4;
  end;
  if (Signal='It') then
  begin
    SkipNr := 1;
    NrOfitems := 5;
  end;
  if (Signal='FfA') then
  begin
    SkipNr := 2;
    NrOfitems := 6;
  end;
  if (Signal='A') then
  begin
    SkipNr := 8;
    NrOfitems := 3;
  end;
  DetectIt:='';
  while NrOfData<Nm*Ns do
  begin
//    DetectStr:='  MONTH:';
//    if TimeStep='Week' then DetectStr:='   WEEK:';
//    if TimeStep='Day' then DetectStr:='   DAY: ';
    while not (DetectIt=DetectStr) do
          readln(OutFile,DetectIt);
    NrOfData := NrOfData+1;
    DetectIt := '';

   for k:=1 to SkipNr do
       readln (OutFile,HlpStr);
   if (Signal='CrA') or (Signal='Cxf') then
    begin
      readln (OutFile,HlpStr,MainStr[1],HlpStr,MainStr[2],
                      HlpStr,MainStr[3],HlpStr,MainStr[4]);
      readln (OutFile,HlpStr,MainStr[5],HlpStr,MainStr[6],
                      HlpStr,MainStr[7]);
    end else
    if (SigNal='Gd') or (Signal='FfA') then
    begin
      readln (OutFile,HlpStr,MainStr[1],HlpStr,MainStr[2],
                      HlpStr,MainStr[3]);
      readln (OutFile,HlpStr,MainStr[4],HlpStr,MainStr[5],
                      HlpStr,MainStr[6]);
    end else
    if (Signal='LrA') or (Signal='RrA') then
      readln (OutFile,HlpStr,MainStr[1],HlpStr,MainStr[2],
                      HlpStr,MainStr[3],HlpStr,MainStr[4])
    else
    if (Signal='It') then
    begin
      readln (OutFile,HlpStr,MainStr[1],HlpStr,MainStr[2],
                      HlpStr,MainStr[4],HlpStr,MainStr[5]);
      readln (OutFile,HlpStr,MainStr[3],HlpStr,MainStr[3],
                      HlpStr,MainStr[3],HlpStr,MainStr[3]);
    end else
    if (Signal='A') then
    begin
      readln (OutFile,HlpStr,MainStr[1],HlpStr,MainStr[2],
                      HlpStr,MainStr[3]);
    end
    else Showmessage ('No output group could be selected');

    for k:=1 to NrOfitems do
    begin
      setlength (Variable[k],NrOfData);
      while Pos(' ',MainStr[k])>0 do
            delete(MainStr[k],Pos(' ',MainStr[k]),1);
      if (MainStr[k]='-') then
         DataMod.Variable[k,NrOfData-1]:=-1
      else
         DataMod.Variable[k,NrOfData-1]:=StringToFlo(MainStr[k]);
    end;

  end; {while NrOfData<Nm*Ns do}

  Closefile (OutFile);

end; {TDataMod.ReadOutputGroup}
{-----------------------------}



procedure TDataMod.ReadGroupData;
{-------------------------------}
var i, j, k   : integer;
    SerialNr  : integer;
    GroupFile : textfile;
    HlpStr    : string[9];
    CodeStr   : string[7];
    ItemStr   : string[10];
begin
  AssignFile(GroupFile,FileName);
  {$I-} Reset(GroupFile); {$I+}
  NrOfLines:=0;
  while not eof (GroupFile) do
  begin
    readln (GroupFile);
    NrOfLines:=NrOflines+1;
  end;
  NrOfData := NrOfLines-6;
  reset (GroupFile);
  readln (GroupFile,CodeStr);
  reset (GroupFile);
  GroupNotRead:=false;
  if CodeStr='"Data f' then
  begin
     readln (GroupFile,GroupTitle);
  end else
  begin
    showmessage ('This frequency group file is only meant for spreadsheet use.'+
                 ' Graph cannot be made');
    GroupNotRead:=true;
    exit;
  end;

  readln (GroupFile,GrTitle1);
  readln (GroupFile,GrTitle2);
  read (GroupFile,HlpStr);
  readln (GroupFile,GroupMark);
  while Pos(' ',GroupMark)>0 do
        delete(GroupMark,Pos(' ',GroupMark),1);
  NrOfitems := 7;
  if (GroupMark='CrA') then NrOfitems := 4;
  if (GroupMark='Zs') or (GroupMark='Dw') then
     NrOfitems := 1;
  if (GroupMark='Gd') then NrOfitems := 4;
  if (GroupMark='LrA') or (GroupMark='RrA') then
      NrOfitems := 4;
  if (GroupMark='It') then NrOfitems := 5;
  if (GroupMark='FfA') then NrOfitems := 5;
  if (GroupMark='A') then NrOfitems := 3;
  if (GroupMark='EaU ') or (GroupMark='Kr') then
      NrOfitems := 1;
  Nm := NrOfData;
  Reset (GroupFile);
  readln (GroupFile,CodeStr);
  for k:=1 to 2 do readln (GroupFile);
  if CodeStr='"Data f' then readln (GroupFile);
  SerialNr:=0;
  for i:=1 to Nm do
  begin
    for j:=1 to Ns do
    begin
      for k:=1 to NrOfitems do
      begin
        if k=1 then read (GroupFile,HlpStr);
        read (GroupFile,ItemStr);
        setlength (Variable[k],SerialNr+1);
        while Pos(' ',ItemStr)>0 do
              delete(ItemStr,Pos(' ',ItemStr),1);
        if (ItemStr='-') or (ItemStr='n.a.') then
           Variable[k,SerialNr]:=0
        else
        begin
          Variable[k,SerialNr]:=StrToFloat(ItemStr);
          if (GroupMark='A') or (GroupMark='FfA') then
             Variable[k,SerialNr]:=100*Variable[k,SerialNr];
        end;
      end; {for k:=1 to NrOfitems do}
      readln(GroupFile);
      SerialNr:=SerialNr+1;
    end; {for j:=1 to Ns do}
  end; {for i:=1 to Nm do }
  closefile (GroupFile);
end; {TDataMod.ReadGroupData}
{---------------------------}



procedure TDataMod.WriteOutputLines(const DocName: string);
{---------------------------------------------------------}
var  OutFile: textfile;
     k: integer;
begin
  AssignFile(OutFile,DocName);
  {$I-} Rewrite(OutFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "' + DocName + '"could not be opened. It may be ' +
      'damaged or in use by another program.');
    exit;
  end;
  for k:=1 to NrOfLines do
    writeln(OutFile,FileLine[k-1]);
  Close(OutFile);
end; {TDataMod.WriteOutputLines}
{------------------------------}



procedure TDataMod.WriteOutputGroup(const DocName: string);
{---------------------------------------------------------}
var  GroupFile: textfile;
     k: byte;
begin
  AssignFile(GroupFile,DocName);
  {$I-} Rewrite(GroupFile); {$I+}
  if ioresult <> 0 then
  begin
    Showmessage('The file "' + DocName + '"could not be opened. It may be ' +
      'damaged or in use by another program.');
    exit;
  end;
  writeln (GroupFile,GroupTitle);
  for k:=1 to NrOfData+3 do
      writeln (GroupFile,FileLine[k-1]);
  writeln (GroupFile,'#');
  Close(GroupFile);
end; {TDataMod.WriteOutputGroup}
{------------------------------}


{******************************************************************************
 Diverse routines
 ******************************************************************************}


function TDataMod.StringToFlo(Str : string) : double;
{---------------------------------------------------}
{accepts comma or point for decimal separator}
var
  OldDecSep : char;
begin
  try
    Result := StrToFloat(Str);
  except
    on EConvertError do begin
      OldDecSep := DecimalSeparator;
      {change to other decimal separator}
      if DecimalSeparator = ',' then
        DecimalSeparator := '.'
      else
        DecimalSeparator := ',';
      Result := StrToFloat(Str);
      {revert to original decimal separator}
      DecimalSeparator := OldDecSep;
    end;
  end;
end; {TSegRegForm.StringToFlo}
{----------------------------}



function TDataMod.Question(const Query: string): boolean;
begin Result := MessageDlg(Query, mtConfirmation, [mbYes, mbNo], 0) = mrYes;
end; {TDataMod.Question}



procedure TDataMod.DataModuleCreate(Sender: TObject);
begin Filename := '';
end;


end.

