unit UExtraUtils;

interface

uses Dialogs, SysUtils, UdataMod, UCalculate;

const MaxLength = 24;         {tbv pathname in Input}

const                         {tbv graphics}
  PosX1=70;
  PosX2=PosX1+600;
  PosY1=70;
  PosY2=PosY1+300;
  LX = PosX2-PosX1;
  LY = PosY2-PosY1;

var
      {Input}
  CalcMethod, NewDir,
  OldDir                   : string;
  CalcDone                 : boolean;
    {Graphics}
  Ymax, Ymin               : array[1..7] of real;
  Gw0                      : array[1..4] of real;
  Xcount                   : array of real;
  Xmax, Xmin               : real;
  MaxY, MinY               : array [1..7] of longint;
  MaxX, MinX               : longint;
  ScaleY,
  DecimY, FactorY          : array[1..7] of integer;
  ScaleX                   : integer;
  RelYdata                 : array[1..7] of array of integer;
  RelXdata                 : array of integer;
  PosValues                : array [1..7] of boolean;
  LegendX, LegendY,
  LegendY1, LegendY2,
  LegendY3                 : string;
  ErrorFile                : textFile;

     {Input}
  procedure CheckData(var DataOK: boolean);
  Procedure CheckInputs;

    {Graphics}
  procedure MaxMin;
  procedure Scaling;
  procedure Relative;

implementation

     {Input}

procedure CheckData(var DataOK: boolean);
{---------------------------------------}
var ii : byte;
    Comment: string;
    SumOfAreas : array [1..4] of real;
    AreaError : boolean;
begin
  Comment := (' Input not saved. Please correct the data');
  DataOk := false;
  AreaError := false;
  for ii:=1 to DataMod.Ns do with DataMod do
  begin
    SumOfAreas[ii] := A[ii] +B[ii];
    if (SumOfAreas[ii]<0) or (SumOfAreas[ii]>1) then
    begin
      ShowMessage ('The sum of areas A and B in season '+IntToStr(ii)+
                   ' must >= 0 and <= 1');
      AreaError := true;
    end;
  end;
  if AreaError then exit;
  if DataMod.Kd=1 then
  if (DataMod.Dd<=DataMod.Dr) or (DataMod.Dr>=DataMod.Dr+DataMod.Dx) then
  begin
     Showmessage ('The drains must be in the transition zone: '+
                  ' Dr < Dd < Dr + Dx');
     exit;
  end;
  DataOk:=true;
end; {CheckData}
{--------------}


procedure CheckInputs;
{--------------------}
var AB, UU {, SUM, XtraIrr}    : real;
    AI, BI         : array [1..4] of real;
    J              : byte;

begin with DataMod do
begin
  Assignfile(ErrorFile, 'Error.lst');
  Rewrite (ErrorFile);
  Writeln (ErrorFile,' THE FOLLOWING ERRORS WERE FOUND IN THE INPUT FILE:');
  Writeln (ErrorFile);

  IF (Ns<1) OR (Ns>4) THEN
      WRITELN (ErrorFile,' Number of seasons NS must be 1, 2, 3 or 4.');
//Total number of years for predictions
  if DataMod.TimeStep='Month' then IF (Nm>120) OR (Nm<1) THEN
      WRITELN (ErrorFile,' Number of months must be > 1 and < 120.');
  if DataMod.TimeStep='Week' then IF (Nm>132) OR (Nm<1) THEN
      WRITELN (ErrorFile,' Number of weeks must be > 1 and < 132.');
  if DataMod.TimeStep='Day' then IF (Nm>365) OR (Nm<1) THEN
      WRITELN (ErrorFile,' Number of days must be > 1 and < 365.');
//Fractions (proportions) of irrigated land A and B

  FOR J:=1 to Ns DO
  BEGIN
    AB := A[J] + B[J];
    if A[J]=-1 then AB:=B[J];
    if B[J]=-1 then AB:=A[J];
    AI[J]:=A[J];
    BI[J]:=B[J];
    if A[J]<>-1 then IF (A[J]>1) OR (A[J]<0) THEN
        WRITELN (ErrorFile,' Irrigated area fraction A in'+
                           ' season',J:2,' must be between 0 and 1.');
    if B[J]<>-1 then IF (B[J]>1) OR (B[J]<0) THEN
        WRITELN (ErrorFile,' Irrigated area fraction B in'+
                           ' season',J:2,' must be between 0 and 1.');
    IF AB>1 THEN
      WRITELN (ErrorFile,' Sum of area fractions A+B in'+
                         ' season',J:2,' must not be greater than 1.');
  END; {FOR J:=1 to Ns do}
//Indices for rice crop
  FOR J:=1 to NS DO
  BEGIN
    IF (A[J]>0.001) THEN IF (RcA[J]<>0) AND (RcA[J]<>1) THEN
        WRITELN (ErrorFile,' The rice crop index RcA in'+
                           ' season',J:2,' must be 0 or 1.');
    IF (B[J]>0.001) THEN IF (RcB[J]<>0) AND (RcB[J]<>1) THEN
        WRITELN (ErrorFile,' The rice crop index RcB in'+
                           ' season',J:2,' must be 0 or 1.');
  END; {FOR J:=1 to Ns do}
//Canal percolation losses and bypass in m3/season per m2 irr.area
  FOR J:=1 to Ns DO
      IF (Lc[J]<0) OR (Io[J]<0) THEN
          WRITELN (ErrorFile,' Irrigation data Lc and Io'+
                             ' in season',J:2,' must be >= 0');
//Seasonal amount of field irrigation, including re-use, and
//potential evapotranspiration of irrigated A crops
  FOR J:=1 to Ns DO
  BEGIN
    IF (A[J]>0) AND (IaA[J]<0) THEN
        WRITELN (ErrorFile,' Irrigation application IaA'+
                           ' in season',J:2,' must be >= 0.');
    IF (A[J]>0) AND (EpA[J]<0) THEN
        WRITELN (ErrorFile,' Potential evaporation EpA'+
                           ' in season',J:2,' must be >= 0.');
  END;
  FOR J:=1 to Ns DO
  BEGIN
    IF (B[J]>0) AND (IaB[J]<0) THEN
        WRITELN (ErrorFile,' Irrigation application IaB'+
                           ' in season',J:2,' must be >= 0.');
    IF (B[J]>0) AND (EpB[J]<0) THEN
        WRITELN (ErrorFile,' Potential evaporation EpB'+
                           ' in season',J:2,' must be >= 0.');
  END;
//Seasonal rainfall and potential evapotranspiration unirrigated land
  FOR J:=1 to Ns DO
  BEGIN
    AB := A[J] + B[J];
    if A[J]=-1 then AB:=B[J];
    if B[J]=-1 then AB:=A[J];
    IF Pp[J]<0 THEN
      WRITELN (ErrorFile,' Rainfall in season',J:2,' must be >= 0.');
    IF (AB<1) and (EpU[J]<=0) THEN
        WRITELN (ErrorFile,' Potential evaporation EpU'+
                           ' in season',J:2,' must be >= 0.');
  END;
//Storage efficiencies of irrigation and rain
  FOR J:=1 to Ns DO
  BEGIN
    AB := A[J] + B[J];
    if A[J]=-1 then AB:=B[J];
    if B[J]=-1 then AB:=A[J];
    IF (A[J]>0.001) THEN IF (FsA[J]<=0) OR (FsA[J]>1) THEN
        WRITELN (ErrorFile,' Storage efficiency FsA in season ',J:2,
                           ' must be > 0 and < 1.');
    IF (B[J]>0.001) THEN IF (FsB[J]<=0) OR (FsB[J]>1) THEN
        WRITELN (ErrorFile,' Storage efficiency FsB in season ',J:2,
                           ' must be > 0 and < 1.');
    UU:=1-AB;
    IF (UU>0.001) THEN IF (FsU[J]<=0) OR (FsU[J]>1) THEN
        WRITELN (ErrorFile,' Storage efficiency FsU in season ',J:2,
                           ' must be > 0 and < 1.');
    IF (UU=0) AND (Kf=1) THEN IF (FsU[J]<=0) OR (FsU[J]>1) THEN
        WRITELN (ErrorFile,' Storage efficiency FsU in season ',J:2,
                           ' must be > 0 and < 1.');
  END;
//Incoming and outgoing grondwater flow
  FOR J:=1 to Ns DO
  BEGIN
    IF (Gi[J]<0) THEN
        WRITELN (ErrorFile,' Incoming groundwater flow Gi'+
                           ' in season',J:2,' must be >= 0.');
    IF (Go[J]<0) THEN
        WRITELN (ErrorFile,' Incoming groundwater flow Gi'+
                           ' in season',J:2,' must be >= 0.');
  END;
//Incoming and outgoing surface flow unirrigated land U
  FOR J:=1 to Ns DO
  BEGIN
    AB := A[J] + B[J];
    if A[J]=-1 then AB:=B[J];
    if B[J]=-1 then AB:=A[J];
    UU:=1-AB;
    IF (UU>0) AND (SiU[J]<0) THEN
        WRITELN (ErrorFile,' Incoming surface flow SiU'+
                           ' in season',J:2,' must be >= 0.');
    IF (UU=0) AND (Kf>0) AND (SiU[J]<0) THEN
        WRITELN (ErrorFile,' Incoming surface flow SiU'+
                           ' in season',J:2,' must be >= 0.');
    IF (UU>0) AND (SoU[J]<0) THEN
        WRITELN (ErrorFile,' Outgoing surface runoff SoU'+
                           ' in season',J:2,' must be >= 0.');
    IF (UU=0) AND (Kf>0) AND (SoU[J]<0) THEN
        WRITELN (ErrorFile,' Outgoing surface runoff SoU'+
                           ' in season',J:2,' must be >= 0.');
    IF (UU=0) AND (Kf>0) AND (SoU[J]<0) THEN
        WRITELN (ErrorFile,' Outgoing surface runoff SoU'+
                           ' in season',J:2,' must be > 0.');
(*
    if (UU>0) and (SoU[J]-SiU[J]>Pp[J]-EPU[J]) and (Pp[J]-EPU[J]>0)then
        WRITELN (ErrorFile,' Outgoing surface runoff SoU'+
                           ' in season',J:2,' is excessive.')
(*
   END;
//Outgoing surface flow irrigated land A and B
  FOR J:=1 to Ns DO
  BEGIN
    IF (A[J]>0) AND (SoA[J]<0) THEN
        WRITELN (ErrorFile,' Outgoing surface runoff SoA'+
                           ' in season',J:2,' must be >= 0.');
    IF (B[J]>0) AND (SoB[J]<0) THEN
        WRITELN (ErrorFile,' Outgoing surface runoff SoB'+
                           ' in season',J:2,' must be >= 0.');
(*
    SUM:=A[J]+B[J];
    if Sum>0 then
       XtraIrr:=IRA[J]+Pp[J]+A[J]*(Gw[J]*Fw[J]+Gu[J])/SUM -EPA[J]
    else
       XtraIrr:=0;
    if XtraIrr<0 then XtraIrr:=0;
    IF (A[J]>0) AND (SoA[J]>XtraIrr) THEN
        WRITELN (ErrorFile,' Surface drainage SoA'+
                           ' in season',J:2,' is excessive.');
    if Sum>0 then
       XtraIrr:=IRB[J]+Pp[J]+B[J]*(Gw[J]*Fw[J]+Gu[J])/SUM -EPB[J]
    else
       XtraIrr:=0;
    if XtraIrr<0 then XtraIrr:=0;
    IF (B[J]>0) AND (SoB[J]>XtraIrr) THEN
        WRITELN (ErrorFile,' Surface drainage SoB'+
                           ' in season',J:2,' is excessive.');
*)
  END;
//Pumping from wells and re-use fraction of well water for irrigation
  FOR J:=1 to Ns DO
  BEGIN
    Gw0[J]:=Gw[J];
    IF (Gw[J]>0) THEN IF (Fw[J]<0) OR (Fw[J]>1) THEN
       WRITELN (ErrorFile,' Fraction Fw for use of well water'+
                          ' in season',J:2,' must be >= 0 and =< 1.');
  END;
(*
//Surface water resources and drainage
  FOR J:=1 to Ns DO
  BEGIN
    IF (A[J]+B[J]>0) AND (Fw[J]*Gw[J]+Gu[J]>0) THEN
    begin
      SurRes := A[J]*IaA[J]+B[J]*IaB[J]+Pp[j]+Fw[J]*Gw[J]+Gu[J];
      SurOff := A[J]*SoA[J]+B[J]*SoB[J];
      IF (SurOff>SurRes) THEN
          WRITELN (ErrorFile,' Surface drainage SoA and/or SoB in season ',J:2,
                             ' is excessive.');
      IF (Fw[J]*Gw[J]+Gu[J]>0) THEN
      begin
  	     IF (A[J]>0) AND (SoA[J]>IaA[J]+Pp[J]) THEN
            WRITELN (ErrorFile,' Surface drainage SoA in season ',J:2,
                               ' is excessive.');
  	     IF (B[J]>0) AND (SoB[J]>IaB[J]+Pp[J]) THEN
            WRITELN (ErrorFile,' Surface drainage SoB in season ',J:2,
                               ' is excessive.');
      end;
   end;
   IF (A[J]+B[J]<1) AND (SoU[J]>SiU[J]+Pp[J]) THEN
      WRITELN (ErrorFile,' Surface runoff SoU in season ',J:2,' is excessive.');
  END;
*)
//Thickness and total porespace of rootzone, transition zone and aquifer
  IF (Dr<0.1) THEN
      WRITELN (ErrorFile,' Rootzone thickness Dr must be greater than 0.1 m.');
  IF (Ptr<=0) OR (Ptr>1) THEN
      WRITELN (ErrorFile,' The porespace Ptr must be > 0 and < 1.');
  IF (Dx<0.1) THEN
      WRITELN (ErrorFile,' Transition zone thickness Dx must be > 0.1.');
  IF (Ptx<=0) OR (Ptx>1) THEN
      WRITELN (ErrorFile,' The porespace Ptx must be > 0 and < 1.');
  IF (Dq<0.1) THEN
      WRITELN (ErrorFile,' Aquifer thickness Dq must be > 0.1.');
  IF (Ptq<=0) OR (Ptq>1) THEN
      WRITELN (ErrorFile,' The porespace Ptq must be > 0 and < 1.');
  FOR J:=1 to Ns DO
  BEGIN
    IF (Dq<1) THEN IF (Gi[J]>0.01) OR (Go[J]>0.01) THEN
        WRITELN (ErrorFile,' Aquifer thickness Dq and ground water flow'+
        ' Gi and/or Go',' in season',J:2,' are not in proportion.');
  END;
//Drainable or refillable porespace and leaching efficiency of rootzone,
//transition zone and aquifer
  IF (Per<=0) OR (Per>Ptr) THEN
      WRITELN (ErrorFile,' Drainable porosity Per must be < total pore'+
                         ' space Ptr and > 0.');
  IF (Pex<=0) OR (Pex>Ptx) THEN
      WRITELN (ErrorFile,' Drainable porosity Pex must be < total pore'+
                         ' space Ptx and > 0.');
  IF (Peq<=0) OR (Peq>Ptq) THEN
      WRITELN (ErrorFile,' Drainable porosity Peq must be < total pore'+
                         ' space Ptq and > 0.');
  IF (Flr<=0) OR (Flx<=0) OR (Flq<=0) THEN
      WRITELN (ErrorFile,' Leaching efficiencies Flr, Flt, and Flq'+
                         ' must be > 0.');
//Iinitial depth of the watertable and critic. depth of capillary rise
  IF Dw0>Dr+Dx+Dq THEN
      WRITELN (ErrorFile,' The watertable must be above bottom of aquifer.');
  IF Dc<=Dr THEN
      WRITELN (ErrorFile,' Critical depth Dc must be > rootzone depth Dr.');
//Salinity Transition zone
  if (Kd=0) and (SCT<0) then
      WRITELN (ErrorFile,' Salinity of the transition zone must be > 0');
  if (Kd=1) then if (SCU<0) or (SCL<0) then
      WRITELN (ErrorFile,' Salinities in the transition zone must be > 0');
//Drain depth
  IF (Kd=1) THEN IF (Dd<=Dr) OR (Dd>Dr+Dx) THEN
      WRITELN (ErrorFile,' Drains must be in the transition zone:'+
                         ' Dr < Dd < Dr+Dx');
//Drainage factors
  IF (Kd=1) THEN IF (QH1<0) OR (QH2<0) THEN
      WRITELN (ErrorFile,' QH1 and/or QH2 values must be > 0');
//seasonal reduction factor for drainage functioning
  IF Kd=1 THEN FOR J:=1 to Ns DO
     IF (Frd[J]<0) OR (Frd[J]>1) THEN
         WRITELN (ErrorFile,' The drainage control factor Frd in'+
                            ' season',J:2,' must be between 0 and 1.');
  closefile (ErrorFile);
end; {with DataMod do}
end; {CheckInputs}
{----------------}


    {Graphics}

{MaxMin is part of Graphics}
{--------------------------}
procedure MaxMin;
var ii, jj, count : integer;
begin
  with DataMod do
  begin
    for ii:=1 to NrOfitems do Ymax[ii] := -1000000;
    for ii:=1 to NrOfitems do Ymin[ii] := 1000000;
    for ii:=1 to NrOfitems do if PosValues[ii] then
        for jj:=0 to DataMod.NrOfData-1 do
        begin
          if Variable[ii,jj]>Ymax[ii] then
             Ymax[ii] := Variable[ii,jj];
          if (Variable[ii,jj]<Ymin[ii]) then
          begin
             Ymin[ii] := Variable[ii,jj];
             if Ymin[ii]<0 then Ymin[ii] := 0;
          end;
        end;

    if (GroupMark='Zs') or (GroupMark='EaU') then
    if PosValues[6] then
    begin
      Ymax[6]:=-1000000;
      Ymin[6]:=1000000;
      for jj:=0 to DataMod.NrOfData-1 do
      begin
        if Variable[6,jj]>Ymax[6] then
           Ymax[6] := Variable[6,jj];
        if (Variable[6,jj]<Ymin[6]) then
        begin
          Ymin[6] := Variable[6,jj];
          if Ymin[6]<0 then Ymin[6] := 0;
        end;
      end;
    end; {if (GroupMark='Zs') or (GroupMark='EaU')) then}

    if (GroupMark='Gd') or (GroupMark='A') then
    begin
      for ii:=1 to 4 do Ymax[ii] := -1000000;
      for ii:=1 to 4 do Ymin[ii] := 1000000;
      for ii:=1 to 4 do if PosValues[ii] then
           for jj:=0 to DataMod.NrOfData-1 do
           begin
             if Variable[ii,jj]>Ymax[ii] then
                Ymax[ii] := Variable[ii,jj];
             if (Variable[ii,jj]<Ymin[ii]) then
             begin
                Ymin[ii] := Variable[ii,jj];
                if Ymin[ii]<0 then Ymin[ii] := 0;
             end;
           end;
    end; { if (GroupMark='Gd ) or (GroupMark='A') then }

    if GroupMark='Dw' then
    begin
      Ymax[5]:=-1000000;
      Ymin[5]:=1000000;
      for jj:=0 to DataMod.NrOfData-1 do
      begin
        if Variable[5,jj]>Ymax[5] then
           Ymax[5] := Variable[5,jj];
        if (Variable[5,jj]<Ymin[5]) then
          Ymin[5] := Variable[5,jj];
      end;
    end; {if (GroupMark='Dw') then}

    Count := 0;
    Setlength(Xcount,Count+1);
    Xcount[Count]:=0;
    for jj:=0 to Nm do for ii:=1 to Ns do
    begin
      Count := Count+1;
      Setlength(Xcount,Count+1);
      Xcount[Count] := Xcount[Count-1] + 1;
    end; {for jj:=0 to Nm-1 do for ii:=1 to Ns do}

  end; {with DataMod do}
end;
{end of Maxmin}
{-------------}


{Scaling is part of Graphics}
{---------------------------}
procedure Scaling;
var ii, jj, HlpNr, Start : integer;
begin

  for ii:=1 to DataMod.NrOfitems do
  begin
    Ymax[ii]:=1.1*Ymax[ii];
    FactorY[ii]:=1;
  end;

  Start:=1;
  HlpNr:=DataMod.NrOfitems;
  if (DataMod.GroupMark='Zs') or (DataMod.GroupMark='EaU') then
  begin
    Start:=6;
    HlpNr:=6;
  end;
  if (DataMod.GroupMark='Gd') then HlpNr:=4;

  if (DataMod.GroupMark<>'Dw') then
  begin

    for ii:=Start to HlpNr do if PosValues[ii] then
    begin
      if (Ymax[ii]<0.01) then
          FactorY[ii]:=1000;
      if (Ymax[ii]>=0.01) and (Ymax[ii]<0.1) then
          FactorY[ii]:=100;
      if (Ymax[ii]<1) and (Ymax[ii]>=0.1) then
          FactorY[ii]:=10;
    end;

    for ii:=Start to HlpNr do if PosValues[ii] then
    if FactorY[ii]>1 then
    begin
      for jj:=0 to DataMod.NrOfData-1 do
        DataMod.Variable[ii,jj]:=FactorY[ii]*DataMod.Variable[ii,jj];
      Ymin[ii]:=FactorY[ii]*Ymin[ii];
      Ymax[ii]:=FactorY[ii]*Ymax[ii];
    end;

    for ii:=Start to HlpNr do if PosValues[ii] then
    begin
      if (Ymax[ii]>=1) and (Ymax[ii]<10) then
      begin
        decimY[ii] := 1;
        MinY[ii] := round (Ymin[ii]-0.5);
        MaxY[ii] := round (Ymax[ii]+1.0);
        ScaleY[ii] := MaxY[ii]-MinY[ii];
        if ScaleY[ii]>10 then ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 2;
      end
      else if Ymax[ii]<25 then
      begin
        decimY[ii] := 1;
        MinY[ii] := 4*round ((Ymin[ii]-2)/4);
        MaxY[ii] := 4*round ((Ymax[ii]+2)/4);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 4;
      end
      else if Ymax[ii]<50 then
      begin
        decimY[ii] := 1;
        MinY[ii] := 5*round ((Ymin[ii]-2.5)/5);
        MaxY[ii] := 5*round ((Ymax[ii]+2.5)/5);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 5;
      end
      else if Ymax[ii]<125 then
      begin
        decimY[ii] := 0;
        MinY[ii] := 10*round ((Ymin[ii]-5)/10);
        MaxY[ii] := 10*round ((Ymax[ii]+5)/10);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 10;
      end
      else if Ymax[ii]<250 then
      begin
        decimY[ii] := 0;
        MinY[ii] := 25*round ((Ymin[ii]-12.5)/25);
        MaxY[ii] := 25*round ((Ymax[ii]+12.5)/25);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 25;
      end
      else if Ymax[ii]<500 then
      begin
        decimY[ii] := 0;
        MinY[ii] := 50*round ((Ymin[ii]-25)/50);
        MaxY[ii] := 50*round ((Ymax[ii]+25)/50);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 50;
      end else
      if Ymax[ii]<1000 then
      begin
        decimY[ii] := 0;
        MinY[ii] := 100*round ((Ymin[ii]-50)/100);
        MaxY[ii] := 100*round ((Ymax[ii]+50)/100);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 100;
      end;
      if Ymax[ii]>=1000 then
      begin
        decimY[ii] := 0;
        MinY[ii] := 1000*round ((Ymin[ii]-500)/1000);
        MaxY[ii] := 1000*round ((Ymax[ii]+500)/1000);
        ScaleY[ii] := (MaxY[ii]-MinY[ii]) div 1000;
      end;
    end; {for ii:=1 to DataMod.NrOfitems do if PosValues[ii] then}

    for ii:=Start to HlpNr do if PosValues[ii] then
    begin
      if ScaleY[ii]>10 then
      begin
        ScaleY[ii] := 10;
        DecimY[ii] := DecimY[ii]+1;
      end;
      if ScaleY[ii]<4 then
      begin
        ScaleY[ii] := 5;
        DecimY[ii] := DecimY[ii]+1;
      end;
    end;

  end; {if (DataMod.GroupMark<>'Dw') then}

  if DataMod.GroupMark='Dw' then
  begin
    decimY[5] := 1;
    MinY[5] := round (Ymin[5]-0.5);
    if YMax[5]<=0 then MaxY[5]:=0;
    if Ymax[5]>0 then MaxY[5] := round (Ymax[5]+0.5);
    ScaleY[5] := MaxY[5]-MinY[5];
    if ScaleY[5]<4 then ScaleY[5]:=4;
  end;

  if (DataMod.GroupMark='FfA') or (DataMod.GroupMark='A') then
    for ii:=Start to HlpNr do if PosValues[ii] then
    begin
      decimY[ii] := 0;
      MinY[ii] := 0;
      MaxY[ii] := 120;
      if DataMod.TimeStep='Week' then MaxY[ii] := 132;
      if DataMod.TimeStep='Day' then MaxY[ii] := 365;
      ScaleY[ii] := 6;
    end;

  if DataMod.GroupMark='Kr' then
  begin
    decimY[5] := 0;
    MinY[5] := 0;
    MaxY[5] := 5;
    ScaleY[5] := 5;
  end;

end;
{end of Scaling}
{--------------}


{Relative is part of Graphics}
{----------------------------}
procedure Relative;
var  count, ii, jj      : integer;
     Start, HlpNr       : integer;
     XdataRel,YdataRel  : real;
     Minimum, Maximum   : real;
begin
  MinX := 0;
  MaxX:= DataMod.Nm;
  Count:=0;
  for jj:=0 to DataMod.NrOfData-1 do
  begin
    Count:=Count+1;
    setlength (RelXdata,Count+1);
    XdataRel := LX*(Xcount[Count]-MinX)/(MaxX-MinX);
    RelXdata[jj] := PosX1+round(XdataRel);
  end;

  Maximum:=0;
  Minimum:=1000000;
  Start:=1;
  HlpNr:=DataMod.NrOfitems;
  if (DataMod.GroupMark='Zs') or (DataMod.GroupMark='EaU') then
  begin
    Start:=6;
    HlpNr:=6;
    Minimum:=MinY[6];
    Maximum:=MaxY[6];
  end;
  if (DataMod.GroupMark='Gd') or (DataMod.GroupMark='A') then
      HlpNr:=4;
  if (DataMod.GroupMark='Dw') or (DataMod.GroupMark='Kr') then
  begin
    Start:=5;
    HlpNr:=5;
    Minimum:=MinY[5];
    Maximum:=MaxY[5];
  end;

  for ii:=Start to HlpNr do if PosValues[ii] then
  begin
    if MaxY[ii]>Maximum then Maximum:=MaxY[ii];
    if MinY[ii]<Minimum then Minimum:=MinY[ii];
  end;

  for ii:=Start to HlpNr do if PosValues[ii] then
      for jj:=0 to DataMod.NrOfData-1 do
      begin
        SetLength (RelYdata[ii],jj+1);
        if (DataMod.Variable[ii,jj]<0) and
           (DataMod.GroupMark<>'Dw') then
              DataMod.Variable[ii,jj]:=0;
          YdataRel :=
            LY*(DataMod.Variable[ii,jj]-Minimum)/(Maximum-Minimum);
          RelYdata[ii,jj] := PosY2-round(YdataRel);
      end;
end;
{---------------}
{end of Relative}


end.
